package iottid

import (
	"crypto"
	"crypto/rand"
	"crypto/rsa"
	"crypto/sha256"
	"crypto/x509"
	"encoding/pem"
	"fmt"
)

// RsaVerifySignWithSha256 RSA校验签名（SHA256）
func RsaVerifySignWithSha256(data []byte, sign []byte, publicKey []byte) (err error) {
	block, _ := pem.Decode(publicKey)
	if block == nil {
		err = fmt.Errorf("key error")
		return
	}
	pub, err := x509.ParsePKIXPublicKey(block.Bytes)
	if err != nil {
		return
	}
	hash := sha256.New()
	hash.Write(data)
	err = rsa.VerifyPKCS1v15(pub.(*rsa.PublicKey), crypto.SHA256, hash.Sum(nil), sign)
	return
}

// RsaSignWithSha256 RSA签名（SHA256）
func RsaSignWithSha256(data []byte, privateKey []byte) (sign []byte, err error) {
	block, _ := pem.Decode(privateKey)
	if block == nil {
		err = fmt.Errorf("key error")
		return
	}
	priv, err := x509.ParsePKCS1PrivateKey(block.Bytes)
	if err != nil {
		return
	}
	hash := sha256.New()
	hash.Write(data)
	sign, err = rsa.SignPKCS1v15(rand.Reader, priv, crypto.SHA256, hash.Sum(nil))
	return
}

// RsaDecrypt RSA解密
func RsaDecrypt(data []byte, privateKey []byte) (decryptedData []byte, err error) {
	block, _ := pem.Decode(privateKey)
	if block == nil {
		err = fmt.Errorf("key error")
		return
	}
	priv, err := x509.ParsePKCS1PrivateKey(block.Bytes)
	if err != nil {
		return
	}
	decryptedData, err = rsa.DecryptPKCS1v15(rand.Reader, priv, data)
	return
}
