package test

import (
	"encoding/hex"
	"iottid"
	"testing"
)

var (
	userUin        = "9666666666666"
	userPrivateKey = `-----BEGIN RSA PRIVATE KEY-----
MIIEpQIBAAKCAQEA1l31yT12UbcVYjPtvfgO8eyi32/ETT5fgnHnbY8OzhcYW5Lh
F7V+e/efMyiiNo+XtWj38JMXMJfvrXa9VnzwKlEZC5n3wki5+qCfxlRXgR5uIO/P
5p8M/qFUqfXx5rwcH2T8q0DAWG6GbYR2iIjFRproJd6x8Cb/VJllmhXMeI7jRp7r
jfuHcVhb5NlJWq+331aYITmKrdqLXE7j2XPvOBZouujjH1wE3HEWjBZOQRbNt8GC
Bgm649n06Yn6NXukUD8DNpC7eNIaCWPuzN5LRYQI1Qd7KSrJiMWgqKYmM/s/eJcV
pdKAy4l43Dsas8KYnjOm8TRxm2DZUQmcslinewIDAQABAoIBAQCoAuqRuCdU8l7D
IhoSiyoDeMlKwAml1N38mhOdrcMXycggdaUP9QLWXISdDxrcEn0ABO5W0qIZRuvm
E6tf7vo44Gj1y84AqwmAooW3ZwFSRKxiCjLy+POxWnbF4uqeQg70mCzkeBKI/M9F
ZM2WQ0QDC4QpsjnaFGaIQtX8B1vDnCH98hEZ/WQFhkVIaeljvZqx7pDgYsP2gF7S
8xdcYDJ1Vy9Gas2vLJ8scpOmWgse6hXVvy8CDmb0tf9we3xEAH8tuI7ZvhfcizTa
0En8WJZIP9osh3zmLgyrVZ0L87iiiNgaQoVkf6q1V5LTEUOYu9q95Q7owEGHzmBo
qRQGzaQxAoGBANrt0gCwd7/VlSMfOUBcf79uHjnYPX+Rbik+EjIHcXmmGuYcsJ3v
t03xuaLyinNPiOmKfQ+7n/cIL8m5Bx1JYkhnd6MAS9U62xAeW5OphiTCAN4stSP1
G8r6YXCgpuwzH+5xlkjyaQAIlYDQpBVzdMNMM0sPvOb6fyxD0iInku6TAoGBAPqq
YyITu4o7TpVnr9hcg3B2ehjxnOc8PTqGLC0hcNq05ZAYusd3ZALkRMVJciuwRgtK
pw9UEenCpottTPfJynKKT0AGMwdpdueZPZINi/XYrBj8z6E2Jag2adj0O1mSAay5
8DhDm20R6DsdrRskAgpH6PC7Y4tn10DlHlYVzQx5AoGBAJFsehulHNZbvIYo/nGn
P+Bb+E36OtebNe7FYXbEBPeGg8Wo9xTiIAPxdpsruxXflhVzvaEOw7JnSL8ZXgVx
Mozf1dN7pePNBajOUYxjhkyyZbsvPV/WOBD7gnA69sZdK2/LGcX46BByo0R+0w/A
sqXr3wKUQKm5aXJw1ouDeBFrAoGACSgUOvhxj1kfQ8Hn4IVwn7kUOLkKvD+tFOg1
0Og50SNuh1b/661mz9w6zuIh84qa5Gqzs5Gknd9oagtyFlMevBRlVLdlQc4Oc+Nb
JmysQizKDJeflgn+Uii6sRwq1tjIiuC377Y4hUF0NESfQDCOioWZ8sFFn6AJcutr
skVVmjECgYEA0VBIt9ku5dQoDB4MwDO3lLRlf/OmkOUBsOFa06wrSoPNxIaksdCs
DUOg4DCVID62kfa6bX+o1G0+/jiPwg2q5NLICy+6Q0L/ifzgnDadYgZTPwb2ZRwM
UihxUaSdcPVrcdqO0idrwwyb3lrt0/LAGmBpMsSKelpieQWpKwqZxL8=
-----END RSA PRIVATE KEY-----`
	deviceData            = "0110021000005D19E2AF671007E10029B0A2ec8f9eabc6fbab64689bef2cf4efec9c0000b4d064e6a59187bc7d08821a03e28184ca0ab30eaa210a74fa9a1122e716cf79f02b310f2ecda3959bc99546dbbe39a7a31328090e9d5da9aa394ba1d84dd040de08573a57d2ef8143df1a4efdb6bf2e7d9d2d08be70e3139193281326efd26e"
	tidSvrCertificatePath = "../conf/server_certificate.pem"
	tidSvrPublicKeyPath   = "../conf/server_publickey.pem"
)

func TestAuthDevice(t *testing.T) {
	deviceData, _ := hex.DecodeString(deviceData)
	t.Logf("device data: %v", deviceData)
	serverData, sessionKey, err := iottid.AuthDevice(userUin, userPrivateKey, deviceData, tidSvrPublicKeyPath)
	if err != nil {
		t.Errorf("auth device via http failed: %s", err)
		return
	}
	t.Logf("server data: %v", serverData)
	t.Logf("session key: %v", sessionKey)
	t.Logf("auth device via http test ok")
}

func TestAuthDeviceHTTPS(t *testing.T) {
	deviceData, _ := hex.DecodeString(deviceData)
	t.Logf("device data: %v", deviceData)
	serverData, sessionKey, err := iottid.AuthDeviceHTTPS(userUin, userPrivateKey, deviceData, tidSvrCertificatePath)
	if err != nil {
		t.Errorf("auth device via https failed: %s", err)
		return
	}
	t.Logf("server data: %v", serverData)
	t.Logf("session key: %v", sessionKey)
	t.Logf("auth device via https test ok")
}
