<?php

use PHPUnit\Framework\TestCase;
use IotTid\Server;

final class ServerTest extends TestCase {

    const userUin = '9666666666666';
    const userPrivateKey = "-----BEGIN RSA PRIVATE KEY-----
MIIEpQIBAAKCAQEA1l31yT12UbcVYjPtvfgO8eyi32/ETT5fgnHnbY8OzhcYW5Lh
F7V+e/efMyiiNo+XtWj38JMXMJfvrXa9VnzwKlEZC5n3wki5+qCfxlRXgR5uIO/P
5p8M/qFUqfXx5rwcH2T8q0DAWG6GbYR2iIjFRproJd6x8Cb/VJllmhXMeI7jRp7r
jfuHcVhb5NlJWq+331aYITmKrdqLXE7j2XPvOBZouujjH1wE3HEWjBZOQRbNt8GC
Bgm649n06Yn6NXukUD8DNpC7eNIaCWPuzN5LRYQI1Qd7KSrJiMWgqKYmM/s/eJcV
pdKAy4l43Dsas8KYnjOm8TRxm2DZUQmcslinewIDAQABAoIBAQCoAuqRuCdU8l7D
IhoSiyoDeMlKwAml1N38mhOdrcMXycggdaUP9QLWXISdDxrcEn0ABO5W0qIZRuvm
E6tf7vo44Gj1y84AqwmAooW3ZwFSRKxiCjLy+POxWnbF4uqeQg70mCzkeBKI/M9F
ZM2WQ0QDC4QpsjnaFGaIQtX8B1vDnCH98hEZ/WQFhkVIaeljvZqx7pDgYsP2gF7S
8xdcYDJ1Vy9Gas2vLJ8scpOmWgse6hXVvy8CDmb0tf9we3xEAH8tuI7ZvhfcizTa
0En8WJZIP9osh3zmLgyrVZ0L87iiiNgaQoVkf6q1V5LTEUOYu9q95Q7owEGHzmBo
qRQGzaQxAoGBANrt0gCwd7/VlSMfOUBcf79uHjnYPX+Rbik+EjIHcXmmGuYcsJ3v
t03xuaLyinNPiOmKfQ+7n/cIL8m5Bx1JYkhnd6MAS9U62xAeW5OphiTCAN4stSP1
G8r6YXCgpuwzH+5xlkjyaQAIlYDQpBVzdMNMM0sPvOb6fyxD0iInku6TAoGBAPqq
YyITu4o7TpVnr9hcg3B2ehjxnOc8PTqGLC0hcNq05ZAYusd3ZALkRMVJciuwRgtK
pw9UEenCpottTPfJynKKT0AGMwdpdueZPZINi/XYrBj8z6E2Jag2adj0O1mSAay5
8DhDm20R6DsdrRskAgpH6PC7Y4tn10DlHlYVzQx5AoGBAJFsehulHNZbvIYo/nGn
P+Bb+E36OtebNe7FYXbEBPeGg8Wo9xTiIAPxdpsruxXflhVzvaEOw7JnSL8ZXgVx
Mozf1dN7pePNBajOUYxjhkyyZbsvPV/WOBD7gnA69sZdK2/LGcX46BByo0R+0w/A
sqXr3wKUQKm5aXJw1ouDeBFrAoGACSgUOvhxj1kfQ8Hn4IVwn7kUOLkKvD+tFOg1
0Og50SNuh1b/661mz9w6zuIh84qa5Gqzs5Gknd9oagtyFlMevBRlVLdlQc4Oc+Nb
JmysQizKDJeflgn+Uii6sRwq1tjIiuC377Y4hUF0NESfQDCOioWZ8sFFn6AJcutr
skVVmjECgYEA0VBIt9ku5dQoDB4MwDO3lLRlf/OmkOUBsOFa06wrSoPNxIaksdCs
DUOg4DCVID62kfa6bX+o1G0+/jiPwg2q5NLICy+6Q0L/ifzgnDadYgZTPwb2ZRwM
UihxUaSdcPVrcdqO0idrwwyb3lrt0/LAGmBpMsSKelpieQWpKwqZxL8=
-----END RSA PRIVATE KEY-----";
    const serverPublicKeyPath = "./conf/server_publickey.pem";
    const serverCertificatePath = "./conf/server_certificate.pem";

    public function testAuthDevice() {
        $deviceDataByteArr = [
            1, 16, 2, 16, 0, 0, 93, 25, 226, 175, 103, 16, 7, 225, 0, 41, 
            176, 162, 236, 143, 158, 171, 198, 251, 171, 100, 104, 155, 
            239, 44, 244, 239, 236, 156, 0, 0, 180, 208, 100, 230, 165, 
            145, 135, 188, 125, 8, 130, 26, 3, 226, 129, 132, 202, 10, 
            179, 14, 170, 33, 10, 116, 250, 154, 17, 34, 231, 22, 207, 
            121, 240, 43, 49, 15, 46, 205, 163, 149, 155, 201, 149, 70, 
            219, 190, 57, 167, 163, 19, 40, 9, 14, 157, 93, 169, 170, 57, 
            75, 161, 216, 77, 208, 64, 222, 8, 87, 58, 87, 210, 239, 129, 
            67, 223, 26, 78, 253, 182, 191, 46, 125, 157, 45, 8, 190, 112, 
            227, 19, 145, 147, 40, 19, 38, 239, 210, 110,
        ];
        $deviceData = '';
        foreach ($deviceDataByteArr as $byte) {
            $deviceData .= chr($byte);
        }
        $server = new Server();
        echo "\ntestAuthDevice\n";
        try {
            $authResult = $server->authDevice(self::userUin, self::userPrivateKey, $deviceData, self::serverPublicKeyPath);
            echo "======================================\n";
            echo "Server data in base64 format: \n" . base64_encode($authResult[0]) . "\n";
            echo "Session token in base64 format: \n" . base64_encode($authResult[1]) . "\n";
            echo "======================================\n";
        } catch (Exception $e) {
            echo "Auth device via http error: " . $e->getMessage() . "\n";
        }
    }

    public function testAuthDeviceHttps() {
        $deviceDataByteArr = [
            1, 16, 2, 16, 0, 0, 93, 25, 226, 175, 103, 16, 7, 225, 0, 41, 
            176, 162, 236, 143, 158, 171, 198, 251, 171, 100, 104, 155, 
            239, 44, 244, 239, 236, 156, 0, 0, 180, 208, 100, 230, 165, 
            145, 135, 188, 125, 8, 130, 26, 3, 226, 129, 132, 202, 10, 
            179, 14, 170, 33, 10, 116, 250, 154, 17, 34, 231, 22, 207, 
            121, 240, 43, 49, 15, 46, 205, 163, 149, 155, 201, 149, 70, 
            219, 190, 57, 167, 163, 19, 40, 9, 14, 157, 93, 169, 170, 57, 
            75, 161, 216, 77, 208, 64, 222, 8, 87, 58, 87, 210, 239, 129, 
            67, 223, 26, 78, 253, 182, 191, 46, 125, 157, 45, 8, 190, 112, 
            227, 19, 145, 147, 40, 19, 38, 239, 210, 110,
        ];
        $deviceData = '';
        foreach ($deviceDataByteArr as $byte) {
            $deviceData .= chr($byte);
        }
        $server = new Server();
        echo "\ntestAuthDeviceHttps\n";
        try {
            $authResult = $server->authDeviceHttps(self::userUin, self::userPrivateKey, $deviceData, self::serverCertificatePath);
            echo "======================================\n";
            echo "Server data in base64 format: \n" . base64_encode($authResult[0]) . "\n";
            echo "Session token in base64 format: \n" . base64_encode($authResult[1]) . "\n";
            echo "======================================\n";
        } catch (Exception $e) {
            echo "Auth device via https error: " . $e->getMessage() . "\n";
        }
    }
    
}