# -*- coding: utf8 -*-

from urllib import request, parse
from Crypto.PublicKey import RSA
from Crypto.Signature import PKCS1_v1_5 as sign_PKCS1_v1_5
from Crypto.Hash import SHA256
from Crypto.Cipher import PKCS1_v1_5 as cipher_PKCS1_v1_5
from Crypto import Random
from Crypto import Hash


def RsaVerifySignWithSha256(signedBytes, originBytes, publicKey):
    """RSA校验签名（SHA256）
    :param signedBytes: 签名数据，类型为bytes
    :param originBytes: 原始数据，类型为bytes
    :param publicKey: 公钥，类型为bytes
    :return: 校验结果，类型为bool
    """

    verifyObj = sign_PKCS1_v1_5.new(RSA.importKey(publicKey))
    sha256Obj = Hash.SHA256.new()
    sha256Obj.update(originBytes)
    return verifyObj.verify(sha256Obj, signedBytes)


def RsaSignWithSha256(originBytes, privateKey):
    """RSA签名（SHA256）
    :param originBytes: 原始数据，类型为bytes
    :param privateKey: 私钥，类型为bytes
    :return: 签名结果，类型为bytes
    """

    signerObj = sign_PKCS1_v1_5.new(RSA.importKey(privateKey))
    sha256Obj = Hash.SHA256.new()
    sha256Obj.update(originBytes)
    return signerObj.sign(sha256Obj)


def RsaEncrypt(originBytes, publicKey):
    """RSA加密
    :param originBytes: 原始数据，类型为bytes
    :param publicKey: 公钥，类型为str
    :return: 加密结果，类型为bytes
    """

    cipherObj = cipher_PKCS1_v1_5.new(RSA.importKey(publicKey))
    return cipherObj.encrypt(originBytes)


def RsaDecrypt(encryptedBytes, privateKey):
    """RSA解密
    :param encryptedBytes: 已加密的数据
    :param privateKey: 私钥
    :return: 解密结果，类型为bytes
    """

    cipherObj = cipher_PKCS1_v1_5.new(RSA.importKey(privateKey))
    return cipherObj.decrypt(encryptedBytes, Random.new().read)
