# -*- coding: utf8 -*-

from sm4.base import *

# SM4算法密钥字节数
SM4_KEY_BYTES_LEN = 16

# SM4算法明文与密文字节模数
SM4_DATA_MOD_BYTES_LEN = 16


def Encrypt(originData, sessionKey):
    """加密
    :param originData: 原始数据，类型为bytes，长度必须为16的倍数
    :param sessionKey: 会话密钥，类型为bytes，长度必须至少为16
    :return: 已加密的数据，类型为bytes，长度与原始数据一致
    """

    if type(sessionKey) != bytes:
        raise TypeError('SM4 key type error')
    if len(sessionKey) < SM4_KEY_BYTES_LEN:
        raise ValueError('SM4 key length error')
    if len(originData) == 0 or len(originData) % SM4_DATA_MOD_BYTES_LEN != 0:
        raise TypeError('Origin data length error')
    key = SM4Key(sessionKey[:SM4_KEY_BYTES_LEN])
    return key.encrypt(originData)


def Decrypt(encryptedData, sessionKey):
    """解密
    :param encryptedData: 已加密的数据，类型为bytes，长度必须为16的倍数
    :param sessionKey: 会话密钥，类型为bytes，长度必须至少为16
    :return: 已解密的数据，类型为bytes，长度与已加密的数据一致
    """

    if type(sessionKey) != bytes:
        raise TypeError('SM4 key type error')
    if len(sessionKey) < SM4_KEY_BYTES_LEN:
        raise ValueError('SM4 key length error')
    if len(encryptedData) % SM4_DATA_MOD_BYTES_LEN != 0:
        raise TypeError('Encrypted data length error')
    key = SM4Key(sessionKey[:SM4_KEY_BYTES_LEN])
    return key.decrypt(encryptedData)
